@@ -4,10 +4,10 @@
 #include <time.h> /* for clock_gettime */
 #include <sys/time.h> /* for timeradd and friends */
 
-#if defined(__APPLE__) && defined(__MACH__)
+#if defined(MISSING_CLOCK_GETTIME)
 /* http://code.google.com/p/semicomplete/issues/detail?id=37
- * OS X doesn't support clock_gettime (in at least OSX <= 10.6) */
-#  include "osx_hacks.h"
+ * OS X doesn't support clock_gettime (in at least OSX <= 10.11) */
+#  include "patch_clock_gettime.h"
 #endif
 
 /* TODO(sissel): Refactor the madness.
