@@ -10,7 +10,8 @@ int cmd_mousemove_relative(context_t *context) {
   int opsync = 0;
   int origin_x = -1, origin_y = -1;
 
-  xdo_active_mods_t *active_mods = NULL;
+  charcodemap_t *active_mods = NULL;
+  int active_mods_n;
   int c;
   typedef enum {
     opt_unused, opt_help, opt_sync, opt_clearmodifiers, opt_polar
@@ -95,28 +96,28 @@ int cmd_mousemove_relative(context_t *context) {
   }
  
   if (clear_modifiers) {
-    active_mods = xdo_get_active_modifiers(context->xdo);
-    xdo_clear_active_modifiers(context->xdo, CURRENTWINDOW, active_mods);
+    xdo_get_active_modifiers(context->xdo, &active_mods, &active_mods_n);
+    xdo_clear_active_modifiers(context->xdo, CURRENTWINDOW, active_mods, active_mods_n);
   }
 
   if (opsync) {
-    xdo_mouselocation(context->xdo, &origin_x, &origin_y, NULL);
+    xdo_get_mouse_location(context->xdo, &origin_x, &origin_y, NULL);
   }
 
-  ret = xdo_mousemove_relative(context->xdo, x, y);
+  ret = xdo_move_mouse_relative(context->xdo, x, y);
 
   if (ret) {
-    fprintf(stderr, "xdo_mousemove_relative reported an error\n");
+    fprintf(stderr, "xdo_move_mouse_relative reported an error\n");
   } else {
     if (opsync) {
       /* Wait until the mouse moves away from its current position */
-      xdo_mouse_wait_for_move_from(context->xdo, origin_x, origin_y);
+      xdo_wait_for_mouse_move_from(context->xdo, origin_x, origin_y);
     }
   }
 
   if (clear_modifiers) {
-    xdo_set_active_modifiers(context->xdo, CURRENTWINDOW, active_mods);
-    xdo_free_active_modifiers(active_mods);
+    xdo_set_active_modifiers(context->xdo, CURRENTWINDOW, active_mods, active_mods_n);
+    free(active_mods);
   }
 
   return ret;
