@@ -1,7 +1,7 @@
 #!/bin/sh
 # Start an ephemeral X server.
 #
-# This is useful for when you want to lauch an X server for a specific
+# This is useful for when you want to launch an X server for a specific
 # process. When that process exits, the X server will be killed.
 # 
 
@@ -71,7 +71,7 @@ cleanup() {
   pkill -KILL -P $$ || true
 }
 
-eval "set -- $( (POSIXLY_CORRECT=1 getopt -s sh +x:w:qh "$@" || echo " "FAIL) | tr -d '\n' )"
+eval "set -- $( (POSIXLY_CORRECT=1 getopt +x:w:qh "$@" || echo " "FAIL) | tr -d '\n' )"
 
 while [ "0$#" -gt 0 ] ; do
   case $1 in
