@@ -1,10 +1,10 @@
 #!/usr/bin/env ruby
 #
 
-require "test/unit"
+require "minitest"
 require "./xdo_test_helper"
 
-class XdotoolCommandGetWindowPidTests < Test::Unit::TestCase
+class XdotoolCommandGetWindowPidTests < MiniTest::Test
   include XdoTestHelper
 
   def assert_is_title(lines)
