@@ -63,6 +63,7 @@ static void _xdo_send_key(const xdo_t *xdo, Window window, charcodemap_t *key,
                           int modstate, int is_press, useconds_t delay);
 static void _xdo_send_modifier(const xdo_t *xdo, int modmask, int is_press);
 
+static int _xdo_query_keycode_to_modifier(XModifierKeymap *modmap, KeyCode keycode);
 static int _xdo_mousebutton(const xdo_t *xdo, Window window, int button, int is_press);
 
 static int _is_success(const char *funcname, int code, const xdo_t *xdo);
@@ -740,6 +741,11 @@ int xdo_select_window_with_click(const xdo_t *xdo, Window *window_ret) {
   XUngrabPointer(xdo->xdpy, CurrentTime);
   XFreeCursor(xdo->xdpy, cursor);
 
+  if (e.xbutton.button != 1) {
+    fprintf(stderr, "window selection aborted with button %d\n", e.xbutton.button);
+    return XDO_ERROR;
+  }
+
   /* If there is no subwindow, then we clicked on the root window */
   if (e.xbutton.subwindow == 0) {
     *window_ret = e.xbutton.root;
@@ -940,9 +946,10 @@ int xdo_click_window_multiple(const xdo_t *xdo, Window window, int button,
       return ret;
     }
     repeat--;
-    if (repeat > 0) {
-      usleep(delay);
-    }
+
+    /* Sleeping even after the last click is important, so that a call to xdo_set_active_modifiers()
+     * right after won't think that the button is still pressed. */
+    usleep(delay);
   } /* while (repeat > 0) */
   return ret;
 } /* int xdo_click_window_multiple */
@@ -1027,9 +1034,10 @@ int xdo_send_keysequence_window_list_do(const xdo_t *xdo, Window window, charcod
   KeySym *keysyms = NULL;
   int keysyms_per_keycode = 0;
   int scratch_keycode = 0; /* Scratch space for temporary keycode bindings */
-  //keysyms = XGetKeyboardMapping(xdo->xdpy, xdo->keycode_low, 
-                                //xdo->keycode_high - xdo->keycode_low,
-                                //&keysyms_per_keycode);
+  keysyms = XGetKeyboardMapping(xdo->xdpy, xdo->keycode_low,
+                                xdo->keycode_high - xdo->keycode_low,
+                                &keysyms_per_keycode);
+
   /* Find a keycode that is unused for scratchspace */
   for (i = xdo->keycode_low; i <= xdo->keycode_high; i++) {
     int j = 0;
@@ -1287,6 +1295,7 @@ static void _xdo_populate_charcode_map(xdo_t *xdo) {
   int keycode, group, groups, level, modmask, num_map;
 
   XDisplayKeycodes(xdo->xdpy, &(xdo->keycode_low), &(xdo->keycode_high));
+  XModifierKeymap *modmap = XGetModifierMapping(xdo->xdpy);
   KeySym *keysyms = XGetKeyboardMapping(xdo->xdpy, xdo->keycode_low,
                                         xdo->keycode_high - xdo->keycode_low + 1,
                                         &xdo->keysyms_per_keycode);
@@ -1319,7 +1328,7 @@ static void _xdo_populate_charcode_map(xdo_t *xdo) {
         xdo->charcodes[idx].key = _keysym_to_char(keysym);
         xdo->charcodes[idx].code = keycode;
         xdo->charcodes[idx].group = group;
-        xdo->charcodes[idx].modmask = modmask;
+        xdo->charcodes[idx].modmask = modmask | _xdo_query_keycode_to_modifier(modmap, keycode);
         xdo->charcodes[idx].symbol = keysym;
 
         idx++;
@@ -1328,6 +1337,7 @@ static void _xdo_populate_charcode_map(xdo_t *xdo) {
   }
   xdo->charcodes_len = idx;
   XkbFreeClientMap(desc, 0, 1);
+  XFreeModifiermap(modmap);
 }
 
 /* context-free functions */
@@ -1504,8 +1514,18 @@ void _xdo_send_key(const xdo_t *xdo, Window window, charcodemap_t *key,
   /* Properly ensure the modstate is set by finding a key
    * that activates each bit in the modifier state */
   int mask = modstate | key->modmask;
+  int use_xtest = 0;
 
   if (window == CURRENTWINDOW) {
+    use_xtest = 1;
+  } else {
+    Window focuswin = 0;
+    xdo_get_focused_window(xdo, &focuswin);
+    if (focuswin == window) {
+      use_xtest = 1;
+    }
+  }
+  if (use_xtest) {
     //printf("XTEST: Sending key %d %s\n", key->code, is_press ? "down" : "up");
     XkbStateRec state;
     XkbGetState(xdo->xdpy, XkbUseCoreKbd, &state);
@@ -1536,6 +1556,31 @@ void _xdo_send_key(const xdo_t *xdo, Window window, charcodemap_t *key,
   }
 }
 
+int _xdo_query_keycode_to_modifier(XModifierKeymap *modmap, KeyCode keycode) {
+  int i = 0, j = 0;
+  int max = modmap->max_keypermod;
+
+  for (i = 0; i < 8; i++) { /* 8 modifier types, per XGetModifierMapping(3X) */
+    for (j = 0; j < max && modmap->modifiermap[(i * max) + j]; j++) {
+      if (keycode == modmap->modifiermap[(i * max) + j]) {
+        switch (i) {
+          case ShiftMapIndex: return ShiftMask; break;
+          case LockMapIndex: return LockMask; break;
+          case ControlMapIndex: return ControlMask; break;
+          case Mod1MapIndex: return Mod1Mask; break;
+          case Mod2MapIndex: return Mod2Mask; break;
+          case Mod3MapIndex: return Mod3Mask; break;
+          case Mod4MapIndex: return Mod4Mask; break;
+          case Mod5MapIndex: return Mod5Mask; break;
+        }
+      } /* end if */
+    } /* end loop j */
+  } /* end loop i */
+
+  /* No modifier found for this keycode, return no mask */
+  return 0;
+}
+
 void _xdo_send_modifier(const xdo_t *xdo, int modmask, int is_press) {
   XModifierKeymap *modifiers = XGetModifierMapping(xdo->xdpy);
   int mod_index, mod_key, keycode;
